@@ -1,6 +1,7 @@
 import collections
 import os
-import re
+
+import regex
 
 from oelint_parser.cls_item import Comment
 from oelint_parser.cls_item import Export
@@ -15,9 +16,11 @@ from oelint_parser.cls_item import Variable
 from oelint_parser.helper_files import expand_term
 from oelint_parser.helper_files import find_local_or_in_layer
 from oelint_parser.inlinerep import inlinerep
+from oelint_parser.rpl_regex import RegexRpl
 
 INLINE_BLOCK = "!!!inlineblock!!!"
 
+
 def get_full_scope(_string, offset, _sstart, _send):
     """get full block of an inline statement
 
@@ -40,7 +43,7 @@ def get_full_scope(_string, offset, _sstart, _send):
         pos += 1
         if scopelevel < 0:
             break
-    return _string[:pos+offset]
+    return _string[:pos + offset]
 
 
 def prepare_lines_subparser(_iter, lineOffset, num, line, raw_line=None):
@@ -59,13 +62,13 @@ def prepare_lines_subparser(_iter, lineOffset, num, line, raw_line=None):
     __func_start_regexp__ = r".*(((?P<py>python)|(?P<fr>fakeroot))\s*)*(?P<func>[\w\.\-\+\{\}\$]+)?\s*\(\s*\)\s*\{"
     res = []
     raw_line = raw_line or line
-    if re.search(r"\\\s*\n", raw_line):
+    if RegexRpl.search(r"\\\s*\n", raw_line):
         _, line = _iter.__next__()
-        while re.search(r"\\\s*\n", line):
+        while RegexRpl.search(r"\\\s*\n", line):
             raw_line += line
             _, line = _iter.__next__()
         raw_line += line
-    elif re.match(__func_start_regexp__, raw_line):
+    elif RegexRpl.match(__func_start_regexp__, raw_line):
         _, line = _iter.__next__()
         stopiter = False
         scope_level = 0
@@ -90,10 +93,10 @@ def prepare_lines_subparser(_iter, lineOffset, num, line, raw_line=None):
                 _, line = _iter.__next__()
             except StopIteration:
                 stopiter = True
-            if re.match("^[A-Za-z0-9#]+", line) or stopiter:
+            if RegexRpl.match("^[A-Za-z0-9#]+", line) or stopiter:
                 if not stopiter:
                     res += prepare_lines_subparser(_iter,
-                                                lineOffset, num, line)
+                                                   lineOffset, num, line)
                 break
             if line.startswith("def "):
                 raw_line = line
@@ -115,7 +118,7 @@ def prepare_lines_subparser(_iter, lineOffset, num, line, raw_line=None):
 
 
 def prepare_lines(_file, lineOffset=0):
-    """break raw file input into preprocessed chunks 
+    """break raw file input into preprocessed chunks
 
     Args:
         _file (string): Full path to file
@@ -171,7 +174,7 @@ def get_items(stash, _file, lineOffset=0):
         ("addtask", __regex_addtask),
         ("taskassign", __regex_taskass),
         ("exportfunc", __regex_export_func),
-        ("vars", __regex_var)
+        ("vars", __regex_var),
     ])
 
     includeOffset = 0
@@ -179,7 +182,7 @@ def get_items(stash, _file, lineOffset=0):
     for line in prepare_lines(_file, lineOffset):
         good = False
         for k, v in _order.items():
-            m = re.match(v, line["cnt"], re.MULTILINE)
+            m = RegexRpl.match(v, line["cnt"], regex.regex.MULTILINE)
             if m:
                 if k == "python":
                     res.append(PythonBlock(
@@ -216,23 +219,29 @@ def get_items(stash, _file, lineOffset=0):
                     inhname = expand_term(stash, _file, m.group("inhname"))
                     if not inhname.endswith(".bbclass"):
                         inhname += ".bbclass"
-                    _path = find_local_or_in_layer(
-                        os.path.join("classes", inhname), 
-                        os.path.dirname(_file))
+                    _path = None
+                    for location in ["classes", "classes-recipe", "classes-global"]:
+                        _path = find_local_or_in_layer(
+                            os.path.join(location, inhname),
+                            os.path.dirname(_file))
+                        if _path:
+                            break
                     if _path:
-                        tmp = stash.AddFile(_path, lineOffset=line["line"], forcedLink=_file)
+                        tmp = stash.AddFile(
+                            _path, lineOffset=line["line"], forcedLink=_file)
                         if any(tmp):
                             includeOffset += max([x.InFileLine for x in tmp])
                     res.append(Variable(
                         _file, line["line"] + includeOffset, line["line"] -
-                        lineOffset, line["raw"], "inherit", m.group("inhname"), line["realraw"],
+                        lineOffset, line["raw"], "inherit", m.group(
+                            "inhname"), line["realraw"],
                         "", ""))
                     good = True
                     break
                 elif k == "export":
                     res.append(Export(
                         _file, line["line"] + includeOffset, line["line"] -
-                        lineOffset, line["raw"], m.group("name").strip() , m.group("value"), line["realraw"]))
+                        lineOffset, line["raw"], m.group("name").strip(), m.group("value"), line["realraw"]))
                     good = True
                     break
                 elif k == "export_noval":
